@@ -37,7 +37,7 @@ void Change::emitUserDialogClosedAfterChange(Akonadi::ITIPHandlerHelper::SendRes
 
 void Change::emitUserDialogClosedBeforeChange(Akonadi::ITIPHandlerHelper::SendResult status)
 {
-    emit dialogClosedBeforeChange(id , status);
+    emit dialogClosedBeforeChange(id, status);
 }
 
 void IncidenceChanger::Private::loadCollections()
@@ -48,15 +48,14 @@ void IncidenceChanger::Private::loadCollections()
     }
 
     m_collectionFetchJob = new Akonadi::CollectionFetchJob(Akonadi::Collection::root(),
-            Akonadi::CollectionFetchJob::Recursive);
+                                                           Akonadi::CollectionFetchJob::Recursive);
 
     m_collectionFetchJob->fetchScope().setContentMimeTypes(KCalendarCore::Incidence::mimeTypes());
     connect(m_collectionFetchJob, &KJob::result, this, &IncidenceChanger::Private::onCollectionsLoaded);
     m_collectionFetchJob->start();
 }
 
-Collection::List IncidenceChanger::Private::collectionsForMimeType(const QString &mimeType,
-        const Collection::List &collections)
+Collection::List IncidenceChanger::Private::collectionsForMimeType(const QString &mimeType, const Collection::List &collections)
 {
     Collection::List result;
     for (const Akonadi::Collection &collection : collections) {
@@ -132,8 +131,8 @@ void IncidenceChanger::Private::onCollectionsLoaded(KJob *job)
         QWidget *parent = change->parentWidget;
 
         const QStringList mimeTypes(incidence->mimeType());
-        collectionToUse = CalendarUtils::selectCollection(parent, /*by-ref*/dialogCode,
-                          mimeTypes, mDefaultCollection);
+        collectionToUse = CalendarUtils::selectCollection(parent, /*by-ref*/ dialogCode,
+                                                          mimeTypes, mDefaultCollection);
         if (dialogCode != QDialog::Accepted) {
             qCDebug(AKONADICALENDAR_LOG) << "User canceled collection choosing";
             change->resultCode = ResultCodeUserCanceled;
@@ -172,8 +171,7 @@ bool IncidenceChanger::Private::isLoadingCollections() const
     return m_collectionFetchJob != nullptr;
 }
 
-void IncidenceChanger::Private::step1DetermineDestinationCollection(const Change::Ptr &change,
-        const Akonadi::Collection &collection)
+void IncidenceChanger::Private::step1DetermineDestinationCollection(const Change::Ptr &change, const Akonadi::Collection &collection)
 {
     QWidget *parent = change->parentWidget.data();
     if (collection.isValid() && hasRights(collection, ChangeTypeCreate)) {
@@ -190,22 +188,22 @@ void IncidenceChanger::Private::step1DetermineDestinationCollection(const Change
                                            << "But it's invalid or doesn't have proper ACLs."
                                            << "isValid = "  << mDefaultCollection.isValid()
                                            << "has ACLs = " << hasRights(mDefaultCollection, ChangeTypeCreate);
-        // else fallthrough, and ask the user.
-        Q_FALLTHROUGH();
-        case DestinationPolicyAsk: {
+            // else fallthrough, and ask the user.
+            Q_FALLTHROUGH();
+        case DestinationPolicyAsk:
             mPendingCreations << change;
             loadCollections(); // Now we wait, collections are being loaded async
             break;
-        }
-        case DestinationPolicyNeverAsk: {
+        case DestinationPolicyNeverAsk:
+        {
             const bool hasRights = this->hasRights(mDefaultCollection, ChangeTypeCreate);
             if (mDefaultCollection.isValid() && hasRights) {
                 step2CreateIncidence(change, mDefaultCollection);
             } else {
                 const QString errorString = showErrorDialog(ResultCodeInvalidDefaultCollection, parent);
                 qCritical() << errorString << "; rights are " << hasRights;
-                change->resultCode = hasRights ? ResultCodeInvalidDefaultCollection :
-                                     ResultCodePermissions;
+                change->resultCode = hasRights ? ResultCodeInvalidDefaultCollection
+                                     : ResultCodePermissions;
                 change->errorString = errorString;
                 cancelTransaction();
             }
@@ -219,8 +217,7 @@ void IncidenceChanger::Private::step1DetermineDestinationCollection(const Change
     }
 }
 
-void IncidenceChanger::Private::step2CreateIncidence(const Change::Ptr &change,
-        const Akonadi::Collection &collection)
+void IncidenceChanger::Private::step2CreateIncidence(const Change::Ptr &change, const Akonadi::Collection &collection)
 {
     Q_ASSERT(change);
 
